# 
# xenopy.jabber - Generic jabber handling code
# Copyright (C) 2005 Jason Chu <jason@archlinux.org>
# 
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 

import xmpp
import log
import xmpp.protocol
import xmpp.dispatcher

conn = None
jid = None
res = None

msgQueue = []

def init(jidstr,resource='', debug=[]):
	global conn, jid, res

	jid = xmpp.JID(jidstr)
	if jid.getResource() == '':
		jid.setResource(resource)
	res = jid.getResource()
	conn = xmpp.Client(jid.getDomain(),debug=debug)

def connect(password, hidden=False, roster=True):
	conres = conn.connect()
	if not conres:
		log.error("Unable to connect to server %s"%jid.getDomain())
		return False
	if conres != 'tls':
		log.warning("Unable to establish secure connection")
	authres = conn.auth(jid.getNode(),password,jid.getResource())
	if not authres:
		log.error("Unable to authorize %s - check login/password"%jid.getNode())
		return False
	if authres != 'sas1':
		log.warning("Unable to perform SASL auth on %s.  Old authentication method used."%jid.getDomain())
	if not hidden:
#		conn.sendInitPresence()
		conn.send(xmpp.dispatcher.Presence(priority=-1))
	if roster:
		conn.getRoster()
	conn.RegisterHandler('message',messageHandler)

def process():
	conn.Process(1)

def messageHandler(conn, msg):
	msgQueue.append(msg)

def getMessage():
	try:
		return msgQueue.pop(0)
	except IndexError:
		return None

def sendMessage(msg=None, to=None, typ=None, body=None, subject=None, wait=None):
	if msg is not None:
		if wait == None:
			return conn.send(msg)
		else:
			return conn.SendAndWaitForResponse(msg, wait)
	else:
		if wait == None:
			return conn.send(xmpp.protocol.Message(to=to, body=body, typ=typ, subject=subject))
		else:
			return conn.SendAndWaitForResponse(xmpp.protocol.Message(to=to, body=body, typ=typ, subject=subject), wait)

def isOnline(jid, priorityMatters=True):
	r = conn.getRoster()
	r = r.getRoster()
	for i in r.getResources(jid):
		pri = r.getPriority(str(jid)+'/'+i)
		if (priorityMatters and pri >= 0) or not priorityMatters:
			return True
	return False

def getRoster():
	r = conn.getRoster()
	return r.getItems()
